<?php

namespace App\Controller\OgBoot\OgLive\Webhook;

use App\Controller\OgBoot\AbstractOgBootController;
use App\Entity\OgLive;
use App\Model\OgLiveStatus;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Validator\Exception\ValidatorException;
use Symfony\Contracts\HttpClient\Exception\ClientExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\RedirectionExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\ServerExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\TransportExceptionInterface;
use Symfony\Contracts\HttpClient\HttpClientInterface;

#[AsController]
class InstallOgLiveResponseAction extends AbstractController
{
    public function __construct(
        protected readonly EntityManagerInterface $entityManager
    )
    {
    }

    #[Route('/og-lives/install/webhook', name: 'install_webhook', methods: ['POST'])]
    public function installWebhook(Request $request): JsonResponse
    {
        $data = json_decode($request->getContent(), true);

        if ($data === null || !isset($data['message'], $data['ogCoreId'], $data['details']['result'])) {
            return new JsonResponse(['error' => 'Invalid or incomplete JSON data'], Response::HTTP_BAD_REQUEST);
        }

        $message = $data['message'];
        $ogCoreId = $data['ogCoreId'];
        $details = $data['details'];
        $result = $details['result'];

        $ogLive = $this->entityManager->getRepository(OgLive::class)->findOneBy(['uuid' => $ogCoreId]);

        if (!$ogLive) {
            return new JsonResponse(['error' => 'OgLive not found'], Response::HTTP_NOT_FOUND);
        }

        $ogLive->setStatus($details['status'] === 'success' ? OgLiveStatus::ACTIVE : OgLiveStatus::FAILED);
        $ogLive->setInstalled($details['status'] === 'success');
        $ogLive->setChecksum($result['id']);
        $ogLive->setDistribution($result['distribution']);
        $ogLive->setKernel($result['kernel']);
        $ogLive->setArchitecture($result['architecture']);
        $ogLive->setRevision($result['revision']);
        $ogLive->setDirectory($result['directory']);

        $this->entityManager->persist($ogLive);
        $this->entityManager->flush();

        return new JsonResponse(data: 'Oglive updated successfully', status: Response::HTTP_OK);
    }
}